==> OpenPatricianDisplay-0.6.0-RC1-sources.jar: ch/sahits/game/graphic/display/dialog/tavern/TavernTravelerDialog.java <==
package ch.sahits.game.graphic.display.dialog.tavern;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.event.NoticeBoardUpdate;
import ch.sahits.game.event.handler.impl.EventHandlerFactory;
import ch.sahits.game.graphic.display.ClientViewState;
import ch.sahits.game.graphic.display.dialog.CloseButtonDialog;
import ch.sahits.game.graphic.display.dialog.util.TavernDialogUtil;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.javafx.control.DecoratedText;
import ch.sahits.game.javafx.control.OpenPatricianLargeWaxButton;
import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.Prototype;
import ch.sahits.game.openpatrician.client.ICityPlayerProxyJFX;
import ch.sahits.game.openpatrician.model.Date;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.IPlayer;
import ch.sahits.game.openpatrician.model.city.impl.TavernState;
import ch.sahits.game.openpatrician.model.people.ITraveler;
import ch.sahits.game.openpatrician.model.ship.IShip;
import ch.sahits.game.openpatrician.model.util.ModelTranslations;
import ch.sahits.game.openpatrician.util.l10n.Locale;
import javafx.beans.binding.BooleanBinding;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.MessageSource;

import javax.annotation.PostConstruct;
import java.util.HashMap;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 26, 2013
 */
@Prototype
@ClassCategory({EClassCategory.DIALOG, EClassCategory.PROTOTYPE_BEAN, EClassCategory.UNRELEVANT_FOR_DESERIALISATION})
public class TavernTravelerDialog extends CloseButtonDialog {
    @Autowired
    private TavernDialogUtil tavernUtil;
    @Autowired
    private Date date;
    @Autowired
    private ClientViewState viewState;
    @Autowired
    private EventHandlerFactory eventHandlerFactory;
    @Autowired
    private Locale locale;

    @Autowired
    private MessageSource messageSource;
    @Autowired
    private ModelTranslations modelTranslator;

    private final ICityPlayerProxyJFX city;
    private final TavernState tavernState;
    private final ITraveler traveler;

    public TavernTravelerDialog(ICityPlayerProxyJFX city) {
        super();
        this.city = city;
        tavernState = city.getCity().getCityState().getTavernState();
        traveler = tavernState.getTraveler();
    }
    @PostConstruct
    private void initializeDialog() {
        setTitle(messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernTravelerDialog.title", new Object[]{}, locale.getCurrentLocal()));
        IPlayer player = city.getPlayer();
        final DateTime arrivalDate = traveler.getArrivalDate();
        String d = date.todisplayString(arrivalDate.getDayOfMonth(), arrivalDate.getMonthOfYear(), arrivalDate.getYear());
        String loadedText = messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernTravelerDialog.dialog",
                new Object[]{city.getPlayer().getLastName(), modelTranslator.getLocalDisplayName(player.getCareerLevel()), player.getName(), traveler.getDestination().getName(), d}, locale.getCurrentLocal());


        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("amount",traveler.getPremium());
        DecoratedText dt = decoratedTextFactory.createDecoratedText(loadedText, parameters);

        final OpenPatricianLargeWaxButton acceptButton = new OpenPatricianLargeWaxButton(messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernBaseSideRoomPersonDialog.accept", new Object[]{}, locale.getCurrentLocal()));
        acceptButton.getStyleClass().add("actionButton");
        int BUTTON_X = (WIDTH - 124) / 2;
        acceptButton.setLayoutX(BUTTON_X);
        int LOWER_BUTTON_Y = CLOSE_BTN_Y_POS - 24;
        acceptButton.setLayoutY(LOWER_BUTTON_Y);
        acceptButton.setOnAction(mouseEvent -> {
            IShip ship = (IShip) city.getActiveShip();
            if (ship != null) {
                ship.addPassenger(traveler);
                eventHandlerFactory.getPassengerLeavingOnShipArrivalHandler(ship, traveler.getDestination(), city.getPlayer(), traveler.getPremium());
                clientEventBus.post(new DisplayMessage("ch.sahits.game.graphic.display.dialog.TavernBaseSideRoomPersonDialog.acceptMessage", new Object[]{ship.getName()}));

                executeOnCloseButtonClicked();
                traveler.leave();
            }
        });
        BooleanBinding disable = disableAcceptBinding();
        acceptButton.setDisable(disable.get());
        disable.addListener((observableValue, oldValue, newValue) -> {
            acceptButton.setDisable(newValue);
        });

        getContent().addAll(dt, acceptButton);
    }

    private BooleanBinding disableAcceptBinding() {
        return new BooleanBinding() {
            {
                super.bind(city.getPlayersShips());
                for (IShip ship : city.getPlayersShips()) {
                    super.bind(ship.passengerPresentProperty());
                }
            }
            @Override
            protected boolean computeValue() {
                if (city.getActiveShip() != null && city.getActiveShip() instanceof IShip) {
                    return !((IShip)city.getActiveShip()).getPassenger().isPresent();
                } else {
                    return false;
                }
            }
        };
    }
    /**
     * Update the notice board and close the dialog.
     */
    @Override
    public void executeOnCloseButtonClicked() {
        ViewChangeCityPlayerProxyJFX proxy = new ViewChangeCityPlayerProxyJFX(viewState.getCurrentCityProxy().get(), EViewChangeEvent.NOTICE_TAVERN);
        clientEventBus.post(new NoticeBoardUpdate(proxy));
        super.executeOnCloseButtonClicked();
    }

    @Override
    public void close() {
        super.close();
        tavernUtil.stopTalkingToPerson(tavernState, city.getPlayer());
    }
}

==> OpenPatricianDisplay-0.7.0-RC1-sources.jar: ch/sahits/game/graphic/display/dialog/tavern/TavernTravelerDialog.java <==
package ch.sahits.game.graphic.display.dialog.tavern;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.event.NoticeBoardUpdate;
import ch.sahits.game.event.handler.impl.EventHandlerFactory;
import ch.sahits.game.graphic.display.ClientViewState;
import ch.sahits.game.graphic.display.dialog.CloseButtonDialog;
import ch.sahits.game.graphic.display.dialog.util.TavernDialogUtil;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.javafx.control.DecoratedText;
import ch.sahits.game.javafx.control.OpenPatricianLargeWaxButton;
import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.Prototype;
import ch.sahits.game.openpatrician.client.ICityPlayerProxyJFX;
import ch.sahits.game.openpatrician.model.Date;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.IPlayer;
import ch.sahits.game.openpatrician.model.city.impl.TavernState;
import ch.sahits.game.openpatrician.model.people.ITraveler;
import ch.sahits.game.openpatrician.model.ship.IShip;
import ch.sahits.game.javafx.util.ModelTranslations;
import ch.sahits.game.openpatrician.util.l10n.Locale;
import javafx.beans.binding.BooleanBinding;
import org.joda.time.DateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.MessageSource;

import javax.annotation.PostConstruct;
import java.util.HashMap;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 26, 2013
 */
@Prototype
@ClassCategory({EClassCategory.DIALOG, EClassCategory.PROTOTYPE_BEAN, EClassCategory.UNRELEVANT_FOR_DESERIALISATION})
public class TavernTravelerDialog extends CloseButtonDialog {
    @Autowired
    private TavernDialogUtil tavernUtil;
    @Autowired
    private Date date;
    @Autowired
    private ClientViewState viewState;
    @Autowired
    private EventHandlerFactory eventHandlerFactory;
    @Autowired
    private Locale locale;

    @Autowired
    private MessageSource messageSource;
    @Autowired
    private ModelTranslations modelTranslator;

    private final ICityPlayerProxyJFX city;
    private final TavernState tavernState;
    private final ITraveler traveler;

    public TavernTravelerDialog(ICityPlayerProxyJFX city) {
        super();
        this.city = city;
        tavernState = city.getCity().getCityState().getTavernState();
        traveler = tavernState.getTraveler();
    }
    @PostConstruct
    private void initializeDialog() {
        setTitle(messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernTravelerDialog.title", new Object[]{}, locale.getCurrentLocal()));
        IPlayer player = city.getPlayer();
        final DateTime arrivalDate = traveler.getArrivalDate();
        String d = modelTranslator.toDisplayString(arrivalDate);
        String loadedText = messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernTravelerDialog.dialog",
                new Object[]{city.getPlayer().getLastName(), modelTranslator.getLocalDisplayName(player.getCareerLevel()), player.getName(), traveler.getDestination().getName(), d}, locale.getCurrentLocal());


        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("amount",traveler.getPremium());
        DecoratedText dt = decoratedTextFactory.createDecoratedText(loadedText, parameters);

        final OpenPatricianLargeWaxButton acceptButton = new OpenPatricianLargeWaxButton(messageSource.getMessage("ch.sahits.game.graphic.display.dialog.TavernBaseSideRoomPersonDialog.accept", new Object[]{}, locale.getCurrentLocal()));
        acceptButton.getStyleClass().add("actionButton");
        int BUTTON_X = (WIDTH - 124) / 2;
        acceptButton.setLayoutX(BUTTON_X);
        int LOWER_BUTTON_Y = CLOSE_BTN_Y_POS - 24;
        acceptButton.setLayoutY(LOWER_BUTTON_Y);
        acceptButton.setOnAction(mouseEvent -> {
            IShip ship = (IShip) city.getActiveShip();
            if (ship != null) {
                ship.addPassenger(traveler);
                eventHandlerFactory.getPassengerLeavingOnShipArrivalHandler(ship, traveler.getDestination(), city.getPlayer(), traveler.getPremium());
                clientEventBus.post(new DisplayMessage("ch.sahits.game.graphic.display.dialog.TavernBaseSideRoomPersonDialog.acceptMessage", new Object[]{ship.getName()}));

                executeOnCloseButtonClicked();
                traveler.leave();
            }
        });
        BooleanBinding disable = disableAcceptBinding();
        acceptButton.setDisable(disable.get());
        disable.addListener((observableValue, oldValue, newValue) -> {
            acceptButton.setDisable(newValue);
        });

        getContent().addAll(dt, acceptButton);
    }

    private BooleanBinding disableAcceptBinding() {
        return new BooleanBinding() {
            {
                super.bind(city.getPlayersShips());
                for (IShip ship : city.getPlayersShips()) {
                    super.bind(ship.passengerPresentProperty());
                }
            }
            @Override
            protected boolean computeValue() {
                if (city.getActiveShip() != null && city.getActiveShip() instanceof IShip) {
                    return !((IShip)city.getActiveShip()).getPassenger().isPresent();
                } else {
                    return false;
                }
            }
        };
    }
    /**
     * Update the notice board and close the dialog.
     */
    @Override
    public void executeOnCloseButtonClicked() {
        ViewChangeCityPlayerProxyJFX proxy = new ViewChangeCityPlayerProxyJFX(viewState.getCurrentCityProxy().get(), EViewChangeEvent.NOTICE_TAVERN);
        clientEventBus.post(new NoticeBoardUpdate(proxy));
        super.executeOnCloseButtonClicked();
    }

    @Override
    public void close() {
        super.close();
        tavernUtil.stopTalkingToPerson(tavernState, city.getPlayer());
    }
}
